@@ -32,8 +32,9 @@ import datetime
 from enum import Enum
 import google.auth
 from google.auth.credentials import Credentials, with_scopes_if_required
+from cryptography.x509 import load_pem_x509_certificate
+from cryptography.hazmat.backends import default_backend
 import google.auth.transport.requests
-import OpenSSL
 import ssl
 from tempfile import TemporaryDirectory
 from typing import (
@@ -54,16 +55,6 @@ class IPTypes(Enum):
     PRIVATE: str = "PRIVATE"
 
 
-class ConnectionSSLContext(ssl.SSLContext):
-    """Subclass of ssl.SSLContext with added request_ssl attribute. This is
-    required for compatibility with pg8000 driver.
-    """
-
-    def __init__(self, *args: Any, **kwargs: Any) -> None:
-        self.request_ssl = False
-        super(ConnectionSSLContext, self).__init__(*args, **kwargs)
-
-
 class TLSVersionError(Exception):
     """
     Raised when the required TLS protocol version is not supported.
@@ -125,13 +116,30 @@ class InstanceMetadata:
     ) -> None:
         self.ip_addrs = ip_addrs
 
-        if enable_iam_auth and not ssl.HAS_TLSv1_3:  # type: ignore
-            raise TLSVersionError(
-                "Your current version of OpenSSL does not support TLSv1.3, "
-                "which is required to use IAM Authentication."
+        self.context = ssl.SSLContext(ssl.PROTOCOL_TLS)
+
+        # verify OpenSSL version supports TLSv1.3
+        if ssl.HAS_TLSv1_3:
+            # force TLSv1.3 if supported by client
+            self.context.minimum_version = ssl.TLSVersion.TLSv1_3
+        # fallback to TLSv1.2 for older versions of OpenSSL
+        else:
+            if enable_iam_auth:
+                raise TLSVersionError(
+                    f"Your current version of OpenSSL ({ssl.OPENSSL_VERSION}) does not "
+                    "support TLSv1.3, which is required to use IAM Authentication.\n"
+                    "Upgrade your OpenSSL version to 1.1.1 for TLSv1.3 support."
+                )
+            logger.warning(
+                "TLSv1.3 is not supported with your version of OpenSSL "
+                f"({ssl.OPENSSL_VERSION}), falling back to TLSv1.2\n"
+                "Upgrade your OpenSSL version to 1.1.1 for TLSv1.3 support."
             )
+            self.context.minimum_version = ssl.TLSVersion.TLSv1_2
+
+        # add request_ssl attribute to ssl.SSLContext, required for pg8000 driver
+        self.context.request_ssl = False  # type: ignore
 
-        self.context = ConnectionSSLContext()
         self.expiration = expiration
 
         # tmpdir and its contents are automatically deleted after the CA cert
@@ -343,12 +351,10 @@ class Instance:
                 metadata_task, ephemeral_task
             )
 
-            x509 = OpenSSL.crypto.load_certificate(
-                OpenSSL.crypto.FILETYPE_PEM, ephemeral_cert
-            )
-            expiration = datetime.datetime.strptime(
-                x509.get_notAfter().decode("ascii"), "%Y%m%d%H%M%SZ"
+            x509 = load_pem_x509_certificate(
+                ephemeral_cert.encode("UTF-8"), default_backend()
             )
+            expiration = x509.not_valid_after
 
             if self._enable_iam_auth:
                 if self._credentials is not None:
